@@ -2,7 +2,7 @@ package DBIx::Skinny;
 use strict;
 use warnings;
 
-our $VERSION = '0.0706';
+our $VERSION = '0.0707';
 
 use DBI;
 use DBIx::Skinny::Iterator;
@@ -29,7 +29,8 @@ sub import {
         dsn             => $args->{dsn},
         username        => $args->{username},
         password        => $args->{password},
-        connect_options => $args->{connect_options},
+        coddnnect_options => $args->{connect_options},
+        on_connect_do   => $args->{on_connect_do},
         dbh             => $args->{dbh}||undef,
         dbd             => $dbd_type ? DBIx::Skinny::DBD->new($dbd_type) : undef,
         schema          => $schema,
@@ -47,7 +48,7 @@ sub import {
         my @functions = qw/
             new
             schema profiler
-            dbh dbd connect connect_info _dbd_type reconnect set_dbh setup_dbd
+            dbh dbd connect connect_info _dbd_type reconnect set_dbh setup_dbd do_on_connect
             call_schema_trigger
             do resultset search single search_by_sql search_named count
             data2itr find_or_new
@@ -82,9 +83,23 @@ sub new {
     my $profiler = delete $attr->{profiler};
     my $dbh      = delete $attr->{dbh};
     my $connect_options = delete $attr->{connect_options};
+    my $on_connect_do = delete $attr->{on_connect_do};
 
     my $self = bless Storable::dclone($attr), $class;
+
+    $self->attribute->{profiler} = $profiler;
+    $attr->{dbd}      = $dbd;
+    $attr->{dbh}      = $dbh;
+    $attr->{profiler} = $profiler;
+    $attr->{on_connect_do} = $on_connect_do;
+
     if ($connection_info) {
+        if ( $connection_info->{on_connect_do} ) {
+            $self->attribute->{on_connect_do} = $connection_info->{on_connect_do};
+        } else {
+            $self->attribute->{on_connect_do} = $on_connect_do;
+        }
+
         if ($connection_info->{dbh}) {
             $self->connect_info($connection_info);
             $self->set_dbh($connection_info->{dbh});
@@ -96,11 +111,8 @@ sub new {
         $self->attribute->{dbd} = $dbd;
         $self->attribute->{dbh} = $dbh;
         $self->attribute->{connect_options} = $connect_options;
+        $self->attribute->{on_connect_do} = $on_connect_do;
     }
-    $self->attribute->{profiler} = $profiler;
-    $attr->{dbd}      = $dbd;
-    $attr->{dbh}      = $dbh;
-    $attr->{profiler} = $profiler;
 
     return $self;
 }
@@ -200,6 +212,10 @@ sub connect {
     $class->connect_info(@_) if scalar @_ >= 1;
 
     my $attr = $class->attribute;
+    my $do_connected;
+    if ( !$attr->{dbh} ) {
+        $do_connected++;
+    }
     $attr->{dbh} ||= DBI->connect(
         $attr->{dsn},
         $attr->{username},
@@ -207,6 +223,10 @@ sub connect {
         { RaiseError => 1, PrintError => 0, AutoCommit => 1, %{ $attr->{connect_options} || {} } }
     ) or Carp::croak("Connection error: " . $DBI::errstr);
 
+    if ( $do_connected && $attr->{on_connect_do} ) {
+        $class->do_on_connect;
+    }
+
     $attr->{dbh};
 }
 
@@ -216,6 +236,21 @@ sub reconnect {
     $class->connect(@_);
 }
 
+sub do_on_connect {
+    my $class = shift;
+
+    my $on_connect_do = $class->attribute->{on_connect_do};
+    if (not ref($on_connect_do)) {
+        $class->do($on_connect_do);
+    } elsif (ref($on_connect_do) eq 'CODE') {
+        $on_connect_do->($class);
+    } elsif (ref($on_connect_do) eq 'ARRAY') {
+        $class->do($_) for @$on_connect_do;
+    } else {
+        Carp::croak('Invalid on_connect_do: '.ref($on_connect_do));
+    }
+}
+
 sub set_dbh {
     my ($class, $dbh) = @_;
     $class->attribute->{dbh} = $dbh;
